/******************************************************************************
*
*  Module Name: BROWSE
*
*  OS/2 Work Place Shell Sample Program
*
*  Copyright (C) 1993 IBM Corporation
*
*      DISCLAIMER OF WARRANTIES.  The following [enclosed] code is
*      sample code created by IBM Corporation. This sample code is not
*      part of any standard or IBM product and is provided to you solely
*      for  the purpose of assisting you in the development of your
*      applications.  The code is provided "AS IS", without
*      warranty of any kind.  IBM shall not be liable for any damages
*      arising out of your use of the sample code, even if they have been
*      advised of the possibility of such damages.                                                    *
*
******************************************************************************/

###   Note: The header preceding this comment will be emitted in all files.
###
###         Any comments to go public should be preceded with '--'
###         Any comments to remain private should be preceded with '#'

#******************************************************************************
#   Include the class definition file for the parent class
#******************************************************************************
include <wpdataf.sc>

#******************************************************************************
#   Define the new class
#******************************************************************************
class:  Browse_O_Matic,
        external stem   = Browse_O_Maticwps,
        local,
        external prefix = Browse_O_Maticwps_,
        classprefix     = Browse_O_MaticM_,
        major version   = 1,
        minor version   = 2;

--
-- CLASS: Browse_O_Matic
--
-- CLASS HIERARCHY:
--
--     SOMObject
--        WPObject
--              WPFileSystem
--                    WPDataFile
--                           Browse_O_Matic
--
-- DESCRIPTION:
--
--    This is the sample Browse_O_Matic object class. This object provides
--    a hex and text dump view for file system objects that are dropped on
--    instances of it.
--
--    An instance of this class can be created as a Workplace object.
--

#******************************************************************************
#   Specify the parent class
#******************************************************************************
parent: WPDataFile;

#******************************************************************************
#   Specify the release order of new methods.  This ensures binary
#   compatability if we change the order of our methods in .c and .csc files.
#******************************************************************************
release order:
        BrowseOMatic,
        DuplicateString,
        ErrorHandler,
        FileExists,
        GetHexLine,
        GetLinesAndColumns,
        GetObjectName,
        GetTextLine,
        LoadObject,
        UnloadObject,

        clsQueryModuleHandle;

#******************************************************************************
#   Passthru IMPLEMENTATION definitions to the .ih file
#******************************************************************************
passthru: C.ih;
        #define   INCL_WIN
        #define   INCL_DOS
        #define   INCL_DOSERRORS
        #define   INCL_DOSMODULEMGR
        #define   INCL_WINSTDDRG
        #define   INCL_WPCLASS
        #include  <os2.h>

        #include  <stdio.h>
        #include  <stdlib.h>
        #include  <string.h>

        /* The number of bytes to display and the length of each line  */
        /* (text format) displayed for Hex display format.             */
        #define  HEX_LINE_LENGTH      69
        #define  HEX_BYTES_PER_LINE   (4 * sizeof( LONG))

        #define  MAX_LINE_LENGTH      255  /* Maximum length of a text line. */
                                           /* Lines longer than this value   */
                                           /* only display the first         */
                                           /* MAX_LINE_LENGTH characters.    */

        /*****************************/
        /* Text object record format */
        /*****************************/
        typedef  struct   _LINERECORD
        {
           PSZ   pszLine;       /* Pointer to beginning of each line of text */
           UINT  unLength;      /* The length of each line of text */

        } LINERECORD;

endpassthru;

#******************************************************************************
#   Passthru PRIVATE definitions to the .ph file
#******************************************************************************
passthru: C.ph;
        /***************/
        /* Window data */
        /***************/
        typedef struct _BROWSEDATA
        {
                USHORT          cb;            /* Size of _BROWSEDATA struct */

                Browse_O_Matic* somSelf;       /* Pointer to instance */
                USEITEM         UseItem;       /* Use Item structure */
                VIEWITEM        ViewItem;      /* Open view structure */

                BOOL            bDisplay;      /* Display mode (Text/Hex) */
                PSZ             pszObjectName; /* Name of object displayed */
                PSZ             pszApplKey;    /* Key used to save window  */
                                               /* coordinates */

                SHORT           sCurrentLine;  /* Current line displayed */
                SHORT           sPageHeight;   /* Height of window in lines */
                SHORT           sTotalLines;   /* Total lines of object */
                SHORT           sCurrentColumn;/* The left most column being */
                                               /* displayed */
                SHORT           sPageWidth;    /* Width of window in columns */
                SHORT           sTotalColumns; /* Total columns of object */
                SHORT           sCharWidth;    /* Width from FONTMETRICS */
                SHORT           sCharHeight;   /* Height from FONTMETRICS */
                SHORT           sCharDescender;/* Descender from FONTMETRICS */
                SHORT           sClientHeight; /* Height of client window */
                SHORT           sClientWidth;  /* Width of client window */

                HWND            hwndVscroll;   /* Verticle Scroll Bar */
                HWND            hwndHscroll;   /* Horizontal Scroll Bar */

                LINERECORD*     pLines;        /* Text line array structure */
                PBYTE           pBuffer;       /* Pointer to object in memory*/
                USHORT          usNumberOfTextColumns; /* Maximum number of *
                                               /* text columns in single line*/
                USHORT          usNumberOfTextLines; /* Maximum number of lines
                                               /* of object displayed as text*/
                ULONG           ulFileLength;  /* Length of file system object*/

        } BROWSEDATA;

        typedef BROWSEDATA *PBROWSEDATA;
endpassthru;

#******************************************************************************
#   Passthru PUBLIC definitions to the .h file
#******************************************************************************
passthru: C.h, after;
endpassthru;

#******************************************************************************
#   Define instance data
#******************************************************************************
data:

#******************************************************************************
#   Define methods
#******************************************************************************
methods:

VOID    BrowseOMatic( BOOL bMode, PSZ pszName);
--
-- METHOD: BrowseOMatic                                   ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Displays a file in the specified format.
--
--      BOOL bMode   - Specifies the format of the view. Supported values:
--                     PMBROWSE_HEX_DISPLAY_MODE
--                     PMBROWSE_TEXT_DISPLAY_MODE
--
--      PSZ  pszName - The name of the file to display. Can't be NULL.
--
-- RETURN:
--
--      N/A
--

PSZ     DuplicateString( PSZ pszString);
--
-- METHOD: DuplicateString                                ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Duplicates a null terminated string. The buffer is allocated using
--   wpAllocMem() and must be freed using wpFreeMem().
--
--      PSZ  pszString - A NULL terminated string.
--
-- RETURN:
--
--      A pointer to the copy of pszString.
--

VOID    ErrorHandler( PSZ pszInfo, APIRET rc);
--
-- METHOD: ErrorHandler                                   ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Displays error information in a PM window.
--
--      PSZ    pszInfo - A description of the error condition.
--      APIRET rc      - The error code from the failing method.
--
-- RETURN:
--
--      N/A
--

BOOL    FileExists( PSZ pszFileName);
--
-- METHOD: FileExists                                     ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Determines if a file exists.
--
--      PSZ    pszFileName - A fully qualified path and file name.
--
-- RETURN:
--
--      TRUE  - The file exists.
--      FALSE - The file does not exist.
--

UINT    GetHexLine( USHORT usLine, PBYTE pBuffer, ULONG ulFileLength,
                                                                  PSZ pszText);
--
-- METHOD: GetHexLine                                     ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Formats 16 bytes of the object for display.
--
--      USHORT usLine       - The number of the line to get.
--      PBYTE  pBuffer      - Pointer to the buffer where the file is loaded in
--      ULONG  ulFileLength - The size of the file.
--      PSZ    pszText      - Buffer to store the formated line in.
--
-- RETURN:
--
--      The length of the formated display line.
--

VOID    GetLinesAndColumns( BOOL bDisplay, PSHORT psTotalLines,
                             PSHORT psTotalColumns, USHORT usNumberOfTextLines,
                             USHORT usNumberOfTextColumns, ULONG ulFileLength);
--
-- METHOD: GetLinesAndColumns                             ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Determines the maximum number of lines and columns based on the current
--   view mode.
--
--      BOOL   bDisplay       - The display mode. Supported values:
--                              PMBROWSE_TEXT_DISPLAY_MODE
--                              PMBROWSE_HEX_DISPLAY_MODE
--      PSHORT psTotalLines   - Return total number of lines.
--      PSHORT psTotalColumns - Return maximum number of columns.
--      USHORT usNumberOfTextLines - The total number of text lines.
--      USHORT usNumberOfTextColumns - The maximum number of text columns.
--      ULONG  ulFileLength   - The length of file.
--
-- RETURN:
--
--      N/A
--

BOOL    GetObjectName( HWND hwnd, PSZ* ppszObjectName);
--
-- METHOD: GetObjectName                                  ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Prompts the user to enter the name of the object.
--
--      HWND   hwnd           - Handle to frame window.
--      PSZ*   ppszObjectName - Address of pointer for object name.
--
-- RETURN:
--
--      TRUE  - The user selected an valid file.
--      FALSE - The user selected cancel.
--

UINT    GetTextLine( USHORT usLine, LINERECORD* pLines, PSZ pszText);
--
-- METHOD: GetTextLine                                    ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Copies a line of text from the object to a buffer.
--
--      USHORT      usLine  - The number of the line to get.
--      LINERECORD* pLines  - Pointer to the line record array.
--      PSZ         pszText - Buffer to store the text in.
--
-- RETURN:
--
--      The length of the line to display.
--

BOOL    LoadObject( PSZ pszObjectName, PULONG pulLength, PBYTE* ppBuffer,
                            LINERECORD** ppLines, PUSHORT pusNumberOfTextLines,
                                               PUSHORT pusNumberOfTextColumns);
--
-- METHOD: LoadObject                                     ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Loads a file into memory and determines the number of text line and
--   maximum number of text columns.
--
--      PSZ     pszObjectName  - Name of the file to load.
--      PULONG  pulLength      - returns the length of the file.
--      PBYTE*  ppBuffer       - returns a pointer to the file in memory.
--      LINERECORD** pLines    - returns a pointer to a line record array.
--      PUSHORT pusNumberOfTextLines   - returns the number of text lines.
--      PUSHORT pusNumberOfTextColumns - returns the maximum number of text
--                                                                     columns.
--
-- RETURN:
--
--      N/A
--

VOID    UnloadObject( PBYTE pBuffer, LINERECORD* pLines);
--
-- METHOD: UnloadObject                                   ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Unloads a file that was loaded. The buffer file and the LINERECORD array
--   are freed.
--
--      PBYTE      ppBuffer - a pointer to the file in memory.
--      LINERECORD pLines   - a pointer to a line record array.
--
-- RETURN:
--
--      N/A
--

#******************************************************************************
#   Specify methods being overridden
#******************************************************************************

override wpDragOver;
--
-- OVERRIDE: wpDragOver                                   ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Rejects objects that are not file system objects from being dropped
--   on the Browse_O_matic.
--

override wpDrop;
--
-- OVERRIDE: wpDrop                                       ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Rejects objects that are not file system objects from being dropped
--   on the Browse_O_matic.
--

override wpMenuItemHelpSelected;
--
-- OVERRIDE: wpMenuItemHelpSelected                       ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Provide help for the Hex and Text view popup menu selections.
--

override wpMenuItemSelected;
--
-- OVERRIDE: wpMenuItemSelected                           ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Opens Hex and Text views.
--

override wpModifyPopupMenu;
--
-- OVERRIDE: wpModifyPopupMenu                            ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Adds selections for Hex and Text view to the popup menu.
--

override wpOpen;
--
-- OVERRIDE: wpOpen                                       ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Opens the Hex and Text views.
--

override wpSetup;
--
-- OVERRIDE: wpSetup                                      ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Initializes the type of the instance of the Browse_O_Matic object to DLL.
--

#******************************************************************************
#   Define class methods
#******************************************************************************
HMODULE clsQueryModuleHandle( ), class;
--
-- METHOD: clsQueryModuleHandle                           ( ) PRIVATE
--                                                        (X) PUBLIC
-- DESCRIPTION:
--
--   Gets the module handle.
--
-- RETURN:
--      NULLHANDLE     - an error occured.
--      Not NULLHANDLE - The handle for DLL containing the Browse_O_Matic
--                       class.
--

#******************************************************************************
#   Specify class methods being overridden
#******************************************************************************
override wpclsInitData, class;
--
-- METHOD: wpclsInitData
--
-- DESCRIPTION:
--
--   Initalize the class data
--

override wpclsQueryDefaultHelp, class;
--
-- METHOD: wpclsQueryDefaultHelp
--
-- DESCRIPTION:
--
--   Provides general help for the Browse_O_Matic instance.
--

override wpclsQueryDefaultView, class;
--
-- METHOD: wpclsQueryDefaultView
--
-- DESCRIPTION:
--
--   Make the default view the Hex view. The user may change this through
--   the settings for each instance of the Browse_O_Matic.
--

override wpclsQueryIconData, class;
--
-- METHOD: wpclsQueryIconData
--
-- DESCRIPTION:
--
--   Provide a icon for each instance of the Browse_O_Matic.
--

override wpclsQueryStyle, class;
--
-- METHOD: wpclsQueryStyle
--
-- DESCRIPTION:
--
--   Set style to never print so that Print is not available on the menu.
--

override wpclsQueryTitle, class;
--
-- METHOD: wpclsQueryTitle
--
-- DESCRIPTION:
--
--   Provide a default title of "Browse-O-Matic".
--



